@@ -74,8 +74,13 @@ class DBStream:
         if isinstance(result, dict):
             if result.get('execute_query'):
                 query_create_table = result.get('execute_query').group(0)
-                schema_name = query_create_table.split('.')[0]
-                table_name = query_create_table.split('.')[1]
+                if len(query_create_table.split('.')) > 1:
+                    schema_name = query_create_table.split('.')[0]
+                    table_name = query_create_table.split('.')[1]
+                else:
+                    schema_name = None
+                    table_name = query_create_table.split('.')[0]
+
                 url = os.environ.get("MONITORING_URL")
                 if url:
                     body = {
@@ -155,7 +160,8 @@ class DBStream:
                 "rows": [[r.get(c) for c in column_names] for r in d['data']],
                 "table_name": d.get('table_name')
             }
-            self.send_data(data=data_to_send, replace=replace, apply_special_env=apply_special_env, **kwargs)
+            if len(data_to_send['columns_name']) > 0:
+                self.send_data(data=data_to_send, replace=replace, apply_special_env=apply_special_env, **kwargs)
 
     def send_temp_data(self, data, schema_prefix, table, column_names, apply_special_env=True):
         data_to_send = {
